# Simple IMAP Client object

This is an IMAP client that encapsulates some of the most common interactions with `imaplib` into an object-oriented structure.

### Installation

```
pip3 install imap-client
```

### Usage

```python
from imap_client import IMAPClient
```
